==> parodia_admin-1.0.2.tar.gz: lib/core/repository/roleGroup.repository.dart <==
// GET
// /api/v1/dashboard/roles/groups/{id}

// PUT
// /api/v1/dashboard/roles/groups/{id}

// DELETE
// /api/v1/dashboard/roles/groups/{id}

// GET
// /api/v1/dashboard/roles/groups

// POST
// /api/v1/dashboard/roles/groups

// POST
// /api/v1/dashboard/roles/groups/{id}/recover
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/role_group.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class RoleGroupRepository {
  ParodiaHTTP? _http;

  RoleGroupRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<RoleGroupDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/roles/groups',
      param: id,
    );

    return ResponseItemDTO<RoleGroupDTO>(
      response: response,
      fromJson: RoleGroupDTO.fromJson,
    );
  }

  Future<ResponseListDTO<RoleGroupDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/roles/groups',
      query: query,
    );

    return ResponseListDTO<RoleGroupDTO>(
      response: response,
      fromJson: RoleGroupDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({RoleGroupBody? roleGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/roles/groups',
      data: roleGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, RoleGroupBody? roleGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/roles/groups',
      param: id,
      data: roleGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/roles/groups',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/roles/groups/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/roleGroup.repository.dart <==
// GET
// /api/v1/dashboard/dashboard/roles/groups/{id}

// PUT
// /api/v1/dashboard/dashboard/roles/groups/{id}

// DELETE
// /api/v1/dashboard/dashboard/roles/groups/{id}

// GET
// /api/v1/dashboard/dashboard/roles/groups

// POST
// /api/v1/dashboard/dashboard/roles/groups

// POST
// /api/v1/dashboard/dashboard/roles/groups/{id}/recover
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/role_group.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class RoleGroupRepository {
  ParodiaHTTP? _http;

  RoleGroupRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<RoleGroupDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/roles/groups',
      param: id,
    );

    return ResponseItemDTO<RoleGroupDTO>(
      response: response,
      fromJson: RoleGroupDTO.fromJson,
    );
  }

  Future<ResponseListDTO<RoleGroupDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/roles/groups',
      query: query,
    );

    return ResponseListDTO<RoleGroupDTO>(
      response: response,
      fromJson: RoleGroupDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({RoleGroupBody? roleGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/roles/groups',
      data: roleGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, RoleGroupBody? roleGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/roles/groups',
      param: id,
      data: roleGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/roles/groups',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/roles/groups/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
